@@ -1,6 +1,10 @@
 package Padre::Document::WebGUI::Asset;
+BEGIN {
+  $Padre::Document::WebGUI::Asset::VERSION = '1.001';
+}
+
+# ABSTRACT: Padre::Document subclass representing a WebGUI Asset
 
-use 5.008;
 use strict;
 use warnings;
 
@@ -15,23 +19,32 @@ use Class::XSAccessor getters => {
     url   => 'url',
 };
 
-# File-faking
-sub basename     { $_[0]->filename }
-sub dirname      { $_[0]->basename }
-sub time_on_file { $_[0]->asset->{revisionDate} }
-sub load_file    { $_[0]->load_asset }
-sub is_new       { 0 }
 
-# Override this to change the highlighter/lexer
+sub basename { $_[0]->filename }
+
+
+sub dirname { $_[0]->basename }
+
+
+sub time_on_file { $_[0]->asset->{revisionDate} }
+
+
+sub load_file { $_[0]->load_asset }
+
+
+sub is_new { 0 }
+
+
 sub lexer { Padre::MimeTypes->get_lexer('text/html') }
 
+
 sub load_asset {
     my ( $self, $assetId, $url ) = @_;
 
     TRACE( "Loading asset $assetId from $url with mimetype " . $self->get_mimetype ) if DEBUG;
 
     # TODO: Investigate whether we should actually subclass Padre::File rather than faking it
-#    $self->{file} = {};
+    #    $self->{file} = {};
 
     $self->{url} = $url;
 
@@ -57,7 +70,7 @@ sub load_asset {
     return $self->process_response( $response->content );
 }
 
-# Override Padre::Document::save_file
+
 sub save_file {
     my $self = shift;
 
@@ -78,7 +91,8 @@ sub save_file {
     my $ua       = LWP::UserAgent->new;
     my $response = $ua->post(
         $url,
-        {   op      => 'padre',
+        {
+            op      => 'padre',
             func    => 'save',
             assetId => $asset->{assetId},
             props   => encode_json($asset),
@@ -98,6 +112,7 @@ sub save_file {
     return $self->process_response( $response->content );
 }
 
+
 sub process_response {
     my $self    = shift;
     my $content = shift;
@@ -127,20 +142,19 @@ sub process_response {
     return 1;
 }
 
-# You can override this to edit something other than the generic 'content' field
+
 sub get_asset_content {
     my $self = shift;
     return $self->asset->{content};
 }
 
-# This is paired with L<get_asset_content> - it gets called to store the editor text
-# back into the appropriate asset field prior to sending hash to server
+
 sub set_asset_content {
     my $self = shift;
     $self->asset->{content} = $self->text_get;
 }
 
-# You can override this to do something entirely different with the asset
+
 sub render {
     my $self  = shift;
     my $asset = $self->asset;
@@ -157,4 +171,87 @@ sub render {
     $self->colourize;
 }
 
+
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Padre::Document::WebGUI::Asset - Padre::Document subclass representing a WebGUI Asset
+
+=head1 VERSION
+
+version 1.001
+
+=head1 METHODS
+
+=head2 asset
+
+Accessor
+
+=head2 url
+
+Accessor
+
+=head2 basename
+
+File-faking accessor
+
+=head2 dirname
+
+File-faking accessor
+
+=head2 time_on_file
+
+File-faking accessor
+
+=head2 load_file
+
+File-faking accessor
+
+=head2 is_new
+
+File-faking accessor
+
+=head2 lexer
+
+Override this to change the highlighter/lexer
+
+=head2 load_asset
+
+=head2 save_file
+
+Override Padre::Document::save_file
+
+=head2 process_response
+
+=head2 get_asset_content
+
+You can override this to edit something other than the generic 'content' field
+
+=head2 set_asset_content
+
+This is paired with L<get_asset_content> - it gets called to store the editor text
+back into the appropriate asset field prior to sending hash to server
+
+=head2 render
+
+You can override this to do something entirely different with the asset
+
+=head2 TRACE
+
+=head1 AUTHOR
+
+Patrick Donelan <pdonelan@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Patrick Donelan.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
