@@ -1,6 +1,9 @@
 package Padre::Plugin::WebGUI;
+BEGIN {
+  $Padre::Plugin::WebGUI::VERSION = '1.001';
+}
 
-use 5.008;
+# ABSTRACT: Developer tools for WebGUI
 use strict;
 use warnings;
 
@@ -9,52 +12,30 @@ use Padre::Logger;
 use Padre::Util ('_T');
 use Padre::Plugin::WebGUI::Assets;
 
-=head1 NAME
-
-Padre::Plugin::WebGUI - Developer tools for WebGUI
-
-=head1 VERSION
-
-Version 0.06
-
-=cut
-
-our $VERSION = '0.06';
-
-=head1 SYNOPSIS
-
-cpan install Padre::Plugin::WebGUI;
-
-Then use it via L<Padre>, The Perl IDE.
-
-=head1 DESCRIPTION
-
-This plugin adds a "WebGUI" item to the Padre plugin menu, with a bunch of WebGUI-oriented features.
-
-=cut
 
 # Used to control dev niceties
 my $DEV_MODE = 0;
 
-# The plugin name to show in the Plugin Manager and menus
+
 sub plugin_name {
     return _T("WebGUI");
 }
 
-# Declare the Padre interfaces this plugin uses
+
 sub padre_interfaces {
     'Padre::Plugin' => 0.43,
-        ;
+      ;
 }
 
-# Register the document types that we want to handle
+
 sub registered_documents {
-    'application/x-webgui-asset'        => 'Padre::Document::WebGUI::Asset',
-        'application/x-webgui-template' => 'Padre::Document::WebGUI::Asset::Template',
-        'application/x-webgui-snippet'  => 'Padre::Document::WebGUI::Asset::Snippet',
-        ;
+    'application/x-webgui-asset'      => 'Padre::Document::WebGUI::Asset',
+      'application/x-webgui-template' => 'Padre::Document::WebGUI::Asset::Template',
+      'application/x-webgui-snippet'  => 'Padre::Document::WebGUI::Asset::Snippet',
+      ;
 }
 
+
 sub plugin_directory_share {
     my $self = shift;
 
@@ -68,7 +49,7 @@ sub plugin_directory_share {
     return;
 }
 
-# called when the plugin is enabled
+
 sub plugin_enable {
     my $self = shift;
 
@@ -89,6 +70,7 @@ sub plugin_enable {
     return 1;
 }
 
+
 # called when the plugin is disabled/reloaded
 sub plugin_disable {
     my $self = shift;
@@ -103,13 +85,14 @@ sub plugin_disable {
     # Unload all private classese here, so that they can be reloaded
     require Class::Unload;
     Class::Unload->unload('Padre::Plugin::WebGUI::Assets');
-    
+
     # I think this would be bad if a doc was open when you reloaded the plugin, but handy when developing
     if ($DEV_MODE) {
         Class::Unload->unload('Padre::Document::WebGUI::Asset');
     }
 }
 
+
 sub menu_plugins {
     my $self = shift;
     my $main = shift;
@@ -122,11 +105,11 @@ sub menu_plugins {
 
     # Turn on Asset Tree as soon as Plugin is enabled
     # Disabled - we can't have this here because menu_plugins is called repeatedly
-#    if ( $self->config_read->{show_asset_tree} ) {
-#        $self->{asset_tree_toggle}->Check(1);
-#        
-#        $self->toggle_asset_tree;
-#    }
+    #    if ( $self->config_read->{show_asset_tree} ) {
+    #        $self->{asset_tree_toggle}->Check(1);
+    #
+    #        $self->toggle_asset_tree;
+    #    }
 
     # Online Resources
     my $resources_submenu = Wx::Menu->new;
@@ -138,11 +121,11 @@ sub menu_plugins {
 
     # About
     Wx::Event::EVT_MENU( $main, $self->{menu}->Append( -1, _T("About"), ), sub { $self->show_about }, );
-    
+
     # Reload (handy when developing this plugin)
     if ($DEV_MODE) {
         $self->{menu}->AppendSeparator;
-        
+
         Wx::Event::EVT_MENU(
             $main,
             $self->{menu}->Append( -1, _T("Reload WebGUI Plugin\tCtrl+Shift+R"), ),
@@ -154,6 +137,7 @@ sub menu_plugins {
     return ( $self->plugin_name => $self->{menu} );
 }
 
+
 sub online_resources {
     my %RESOURCES = (
         'Bug Tracker' => sub {
@@ -187,6 +171,7 @@ sub online_resources {
     return map { $_ => $RESOURCES{$_} } sort { $a cmp $b } keys %RESOURCES;
 }
 
+
 sub show_about {
     my $self = shift;
 
@@ -197,7 +182,7 @@ sub show_about {
 WebGUI Plugin for Padre
 http://patspam.com
 END_MESSAGE
-    $about->SetVersion($VERSION);
+    $about->SetVersion($Padre::Plugin::WebGUI::VERSION);
 
     # Show the About dialog
     Wx::AboutBox($about);
@@ -205,11 +190,10 @@ END_MESSAGE
     return;
 }
 
-sub ping {1}
 
-# toggle_asset_tree
-# Toggle the asset tree panel on/off
-# N.B. The checkbox gets checked *before* this method runs
+sub ping { 1 }
+
+
 sub toggle_asset_tree {
     my $self = shift;
 
@@ -232,6 +216,7 @@ sub toggle_asset_tree {
     return;
 }
 
+
 sub asset_tree {
     my $self = shift;
 
@@ -241,56 +226,83 @@ sub asset_tree {
     return $self->{asset_tree};
 }
 
-=head1 AUTHOR
 
-Patrick Donelan C<< <pat at patspam.com> >>
+1;
 
-=head1 BUGS
+__END__
+=pod
 
-Please report any bugs or feature requests to C<bug-padre-plugin-webgui at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Padre-Plugin-WebGUI>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+=head1 NAME
 
-=head1 SUPPORT
+Padre::Plugin::WebGUI - Developer tools for WebGUI
 
-You can find documentation for this module with the perldoc command.
+=head1 VERSION
 
-    perldoc Padre::Plugin::WebGUI
+version 1.001
 
+=head1 SYNOPSIS
 
-You can also look for information at:
+cpan install Padre::Plugin::WebGUI;
 
-=over 4
+Then use it via L<Padre>, The Perl IDE.
 
-=item * RT: CPAN's request tracker
+=head1 DESCRIPTION
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Padre-Plugin-WebGUI>
+This plugin adds a "WebGUI" item to the Padre plugin menu, with a bunch of WebGUI-oriented features.
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=head1 METHODS
 
-L<http://annocpan.org/dist/Padre-Plugin-WebGUI>
+=head2 plugin_name
 
-=item * CPAN Ratings
+The plugin name to show in the Plugin Manager and menus
 
-L<http://cpanratings.perl.org/d/Padre-Plugin-WebGUI>
+=head2 padre_interfaces
 
-=item * Search CPAN
+Declare the Padre interfaces this plugin uses
 
-L<http://search.cpan.org/dist/Padre-Plugin-WebGUI/>
+=head2 registered_documents
 
-=back
+Register the document types that we want to handle
+
+=head2 plugin_directory_share
+
+=head2 plugin_enable
+
+called when the plugin is enabled
+
+=head2 plugin_disable
+
+=head2 menu_plugins
+
+=head2 online_resources
+
+=head2 show_about
+
+=head2 ping
+
+=head2 toggle_asset_tree
+
+Toggle the asset tree panel on/off
+N.B. The checkbox gets checked *before* this method runs
+
+=head2 asset_tree
+
+=head2 TRACE
 
 =head1 SEE ALSO
 
 WebGUI - http://webgui.org
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2009 Patrick Donelan http://patspam.com, all rights reserved.
+Patrick Donelan <pdonelan@cpan.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Patrick Donelan.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
